summaryrefslogtreecommitdiffstats
path: root/chromium/chrome/browser/ui/webui/tab_strip/tab_strip_ui.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2022-09-07 13:12:05 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2022-11-09 10:02:59 +0000
commit33fc33aa94d4add0878ec30dc818e34e1dd3cc2a (patch)
treef6af110909c79b2759136554f1143d8b0572af0a /chromium/chrome/browser/ui/webui/tab_strip/tab_strip_ui.h
parent7d2c5d177e9813077a621df8d18c0deda73099b3 (diff)
BASELINE: Update Chromium to 104.0.5112.120
Change-Id: I5d2726c2ab018d75d055739b6ba64317904f05bb Reviewed-on: https://codereview.qt-project.org/c/qt/qtwebengine-chromium/+/438935 Reviewed-by: Allan Sandfeld Jensen <allan.jensen@qt.io>
Diffstat (limited to 'chromium/chrome/browser/ui/webui/tab_strip/tab_strip_ui.h')
-rw-r--r--chromium/chrome/browser/ui/webui/tab_strip/tab_strip_ui.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/chromium/chrome/browser/ui/webui/tab_strip/tab_strip_ui.h b/chromium/chrome/browser/ui/webui/tab_strip/tab_strip_ui.h
index 70dea1dccc0..d28ce8e76d7 100644
--- a/chromium/chrome/browser/ui/webui/tab_strip/tab_strip_ui.h
+++ b/chromium/chrome/browser/ui/webui/tab_strip/tab_strip_ui.h
@@ -39,10 +39,12 @@ class TabStripUI : public ui::MojoWebUIController,
void BindInterface(
mojo::PendingReceiver<tab_strip::mojom::PageHandlerFactory> receiver);
// Initialize TabStripUI with its embedder and the Browser it's
// running in. Must be called exactly once. The WebUI won't work until
// this is called.
void Initialize(Browser* browser, TabStripUIEmbedder* embedder);
+ void Deinitialize();
// The embedder should call this whenever the result of
// Embedder::GetLayout() changes.
@@ -39,10 +39,12 @@ class TabStripUI : public ui::MojoWebUIController,
void BindInterface(
mojo::PendingReceiver<tab_strip::mojom::PageHandlerFactory> receiver);
- // Initialize TabStripUI with its embedder and the Browser it's
- // running in. Must be called exactly once. The WebUI won't work until
- // this is called.
+ // Initialize TabStripUI with its embedder and the Browser it's running in.
+ // Must be called exactly once. The WebUI won't work until this is called.
+ // |Deinitialize| is called during |embedder|'s destructor. It release the
+ // references taken previously and release the objects depending on them.
void Initialize(Browser* browser, TabStripUIEmbedder* embedder);